<?php

namespace Bixo\Niche\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Niche\Events\NicheAction as NicheActionEvent;
use Bixo\Niche\Notifications\NicheAction as NicheActionNotification;
use Litepie\Actions\Concerns\AsAction;

class NicheAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the NicheActionEvent.
     *
     * @param   NicheActionEvent  $event
     * @return mixed
     */
    public function handle(NicheActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $niche.
     *
     * @param   NicheActionEvent  $event
     * @return void
     */
    public function create(NicheActionEvent $event)
    {
        $client = $event->niche->client;
        Notification::send($client, new NicheActionNotification($event));
    }

    /**
     * Handle the NicheActionEvent as a listener.
     *
     * @param   NicheActionEvent  $event
     * @return mixed
     */
    public function asListener(NicheActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   NicheActionEvent  $event
     * @return bool
     */
    private function isAllowed(NicheActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
