<?php

namespace Bixo\Niche\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Niche\Events\NicheLocationAction as NicheLocationActionEvent;
use Bixo\Niche\Notifications\NicheLocationAction as NicheLocationActionNotification;
use Litepie\Actions\Concerns\AsAction;

class NicheLocationAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the NicheLocationActionEvent.
     *
     * @param   NicheLocationActionEvent  $event
     * @return mixed
     */
    public function handle(NicheLocationActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $niche_location.
     *
     * @param   NicheLocationActionEvent  $event
     * @return void
     */
    public function create(NicheLocationActionEvent $event)
    {
        $client = $event->niche_location->client;
        Notification::send($client, new NicheLocationActionNotification($event));
    }

    /**
     * Handle the NicheLocationActionEvent as a listener.
     *
     * @param   NicheLocationActionEvent  $event
     * @return mixed
     */
    public function asListener(NicheLocationActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   NicheLocationActionEvent  $event
     * @return bool
     */
    private function isAllowed(NicheLocationActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
