<?php

namespace Bixo\Niche\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Niche\Events\NicheLocationWorkflow as NicheLocationWorkflowEvent;
use Bixo\Niche\Notifications\NicheLocationWorkflow as NicheLocationWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class NicheLocationWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(NicheLocationWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $niche_location is submitted.
     *
     * @param NicheLocationWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(NicheLocationWorkflowEvent $event)
    {
        $client = $event->niche_location->client;
        Notification::send($client, new NicheLocationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $niche_location is published.
     *
     * @param NicheLocationWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(NicheLocationWorkflowEvent $event)
    {
        $client = $event->niche_location->client;
        Notification::send($client, new NicheLocationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $niche_location is approved.
     *
     * @param NicheLocationWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(NicheLocationWorkflowEvent $event)
    {
        $client = $event->niche_location->client;
        Notification::send($client, new NicheLocationWorkflowNotification($event));
    }

    /**
     * Handles the $niche_location workflow event as a listener.
     *
     * @param NicheLocationWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(NicheLocationWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
