<?php

namespace Bixo\Niche\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Niche\Events\NicheUserAction as NicheUserActionEvent;
use Bixo\Niche\Notifications\NicheUserAction as NicheUserActionNotification;
use Litepie\Actions\Concerns\AsAction;

class NicheUserAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the NicheUserActionEvent.
     *
     * @param   NicheUserActionEvent  $event
     * @return mixed
     */
    public function handle(NicheUserActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $niche_user.
     *
     * @param   NicheUserActionEvent  $event
     * @return void
     */
    public function create(NicheUserActionEvent $event)
    {
        $client = $event->niche_user->client;
        Notification::send($client, new NicheUserActionNotification($event));
    }

    /**
     * Handle the NicheUserActionEvent as a listener.
     *
     * @param   NicheUserActionEvent  $event
     * @return mixed
     */
    public function asListener(NicheUserActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   NicheUserActionEvent  $event
     * @return bool
     */
    private function isAllowed(NicheUserActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
