<?php

namespace Bixo\Niche\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Niche\Events\NicheUserWorkflow as NicheUserWorkflowEvent;
use Bixo\Niche\Notifications\NicheUserWorkflow as NicheUserWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class NicheUserWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(NicheUserWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $niche_user is submitted.
     *
     * @param NicheUserWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(NicheUserWorkflowEvent $event)
    {
        $client = $event->niche_user->client;
        Notification::send($client, new NicheUserWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $niche_user is published.
     *
     * @param NicheUserWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(NicheUserWorkflowEvent $event)
    {
        $client = $event->niche_user->client;
        Notification::send($client, new NicheUserWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $niche_user is approved.
     *
     * @param NicheUserWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(NicheUserWorkflowEvent $event)
    {
        $client = $event->niche_user->client;
        Notification::send($client, new NicheUserWorkflowNotification($event));
    }

    /**
     * Handles the $niche_user workflow event as a listener.
     *
     * @param NicheUserWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(NicheUserWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
