<?php

namespace Bixo\Niche\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Niche\Models\NicheLocation;

class NicheLocationPolicy
{


    /**
     * Determine if the given user can view the niche_location.
     *
     * @param Authenticatable $user
     * @param NicheLocation $niche_location
     *
     * @return bool
     */
    public function view(Authenticatable $user, NicheLocation $niche_location)
    {
        if ($authUser->canDo('niche.niche_location.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $niche_location->is_owner;
    }

    /**
     * Determine if the given user can create a niche_location.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('niche.niche_location.create');
    }

    /**
     * Determine if the given user can update the given niche_location.
     *
     * @param Authenticatable $user
     * @param NicheLocation $niche_location
     *
     * @return bool
     */
    public function update(Authenticatable $user, NicheLocation $niche_location)
    {
        if ($user->canDo('niche.niche_location.edit') && $user->isAdmin()) {
            return true;
        }

        return $niche_location->is_owner;
    }

    /**
     * Determine if the given user can delete the given niche_location.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, NicheLocation $niche_location)
    {
        return $niche_location->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
