<?php

namespace Bixo\Niche\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Niche\Niches;

class NicheServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'niche');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'niche');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Niche\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Niche\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Niche\Providers\EventServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.niche', function($app)
        {
            return $this->app->make(Niche::class);
        });
    }

    /**
     * Merges user's and niche's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.niche'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/niche.php', 'bixo.niche.niche'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/niche_user.php', 'bixo.niche.niche_user'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/niche_location.php', 'bixo.niche.niche_location'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.niche'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/niche')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/niche')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/niche')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
